@@ -17,10 +17,10 @@ def upload(project, file):
     executable = project.vs_client_path
     server = project.file_server_url
     if not executable or not server:
-        print 'Uploader location or file server URL missing.'
+        print('Uploader location or file server URL missing.')
         sys.exit(1)
     if not os.path.isfile(file):
-        print '%s is not a file.' % file
+        print('%s is not a file.' % file)
         sys.exit(1)
     file = os.path.abspath(file)
     usr, sid = login(project)
