@@ -4,6 +4,7 @@ import docker.auth
 from sbdk.error import SbdkError
 from .runner import Runner, ImageRunner
 from .shell import Shell, Bash, SSH
+from .utils import find_image, parse_repository_tag
 from sbgsdk.util import import_name
 
 
@@ -36,23 +37,3 @@ def make_shell(project, **kwargs):
     else:
         raise SbdkError("Unknown shell: '%s'" % kind)
 
-
-def find_image(docker_client, image_id):
-    images = docker_client.images()
-    repo_name = None
-    try:
-        registry, repo_name = docker.auth.resolve_repository_name(image_id)
-    except:
-        pass
-
-    def flt(x):
-        x['Id'].startswith(image_id) or x['Repository'] == repo_name
-
-    return (filter(flt, images) or [None])[0]
-
-
-def ensure_image(docker_client, image):
-    img = find_image(docker_client, image)
-    if not img:
-        docker_client.pull(image)
-    # hope for the best
