@@ -1,6 +1,7 @@
 import logging
 
 import re
+import requests
 from sys import stdout
 
 from subprocess import Popen
@@ -16,9 +17,6 @@ ALLOWED_CHARS_RE = re.compile('^[a-z0-9]$')
 def dockerize(username):
     return ''.join([chr if re.match(ALLOWED_CHARS_RE, chr) else '_' for chr in username.lower()])
 
-# def dockerize(username):
-#    return ''.join([c.lower() if (c.isalnum() or c == '_') else '' for c in username])  .decode('utf-8').encode('idna')
-
 
 def repo_name(project, user):
     saved_user = project.state.get('username')
@@ -110,18 +108,35 @@ class Container(object):
     def push(self):
         if not self.image:
             raise SbdkError("Container image not committed yet!")
-        push = Popen(['docker', 'push', self.repository], stdout=stdout)
+        push = Popen(['docker', 'push', self.project.repo_name], stdout=stdout)
         push.wait()
 
     def load_credentials(self, renew=False):
         cfg = load_config()
-        if renew or not cfg:
+        session_id = cfg.get(self.project.docker_registry_url, None).get('password', None) if cfg.get(
+            self.project.docker_registry_url, None) else None
+        resp = requests.get(self.project.schema_server_url + '/auth', headers={"session-id": session_id}, verify=False)
+
+        if renew or resp.status_code != 200:
             self._user, self._token = login(self.project)
             store_credentials(self.project.docker_registry_url, self._user, self._token, cfg)
+
         else:
             self._user = cfg[self.project.docker_registry_url]['username']
             self._token = cfg[self.project.docker_registry_url]['password']
 
+
+    def check_privilege(self):
+        resp = requests.get('%s/repo/%s/%s' %(self.project.schema_server_url, self.project.state['username'],
+                                              self.project.state['project_name']), headers={"session-id": self._token},
+                            verify=False)
+        contributors = resp.json()['contributors'] if resp.json().get('contributors', None) else []
+        if (resp.status_code == 404 and self.project.state['username'] == self._user) or \
+                (resp.status_code == 200 and (self._user == resp.json()['owner'] or self._user in contributors)):
+            return True
+        return False
+
+
     @property
     def tag(self):
         return self.image['Id'][:16]
\ No newline at end of file
